/* 	CommentTemplate.java
 *	Copyright (c) 2003-2004, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Nov 14, 2003
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.typewriter;

import java.io.PrintWriter;
import java.util.Vector;

import org.brains2b.util.StringHelper;

/** 
 * Create a comment in a ClassTemplate
 * 
 * <p>TODO this should also be used to create Javadoc and comments for methods
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [11/14/2002]
 */
public class CommentTemplate implements Template {
	protected Vector m_content=new Vector();
	private Template m_parent;

	
	/**
	 * Constructor
	 */
	public CommentTemplate() {
		super();
	}

	/* (non-Javadoc)
	 * @see org.brains2b.typewriter.Template#addImport(java.lang.String)
	 */
	public void addImport(String name) {
		m_parent.addImport(name);
	}

	/**
	 * get the Class name without the package
	 * @param name String, a classname with or without a package
	 * @return String, the classname without the package 
	 * @deprecated use <code>TypeWriterHelper.getClassName(String)</code>
	 */
	public String getObjectName(String name) {
		return TypeWriterHelper.getClassName(name);
	}

	/* (non-javadoc)
	 * @see org.brains2b.typewriter.Template#getParent()
	 */
	public Template getParent() {
		return m_parent;
	}

	/* (non-javadoc)
	 * @see org.brains2b.typewriter.Template#setParent(Template)
	 */
	public void setParent(Template t) {
		m_parent=t;
	}

	/* (non-javadoc)
	 * @see org.brains2b.typewriter.Template#write(PrintWriter, int)
	 */
	public void write(PrintWriter writer, int indent) {
		String spc=StringHelper.leftPad(""," ",indent*4);
		writer.print(spc);
		writer.println("/*");
		for (int i=0;i<m_content.size();i++) {
			writer.print(spc + " * ");
			writer.println(m_content.get(i));
		}
		writer.print(spc);
		writer.println(" */");
	}

	/**
	 * add a comment line to the content of this template.
	 * <p>The line-end will be added by this Template
	 * @param text String, a line to add to the content
	 */
	public void addText(String text) {
			m_content.add(text);
	}

	/**
	 * get the content for this template
	 * <p>The vector will either contain Strings or other ContentTemplates
	 * @return Vector, a list of objects contained in this template, will always
	 * return a Vector even if there is no content.
	 */
	public Vector getContent() {
		return m_content;
	}

	/**
	 * Set the content for this Template
	 * <p>The vector should contain either contain Strings or other ContentTemplates
	 * @param content Vector, a list of objects contained in this template, if null is inserted
	 * the content of this ContentTemplate will be removed and getContent() will return
	 * an empty Vector, not null.
	 */
	public void setContent(Vector content) {
		if (content==null) {
			m_content.removeAllElements();
		} else {
			m_content = content;
		}
	}
}
