/* 	KeyWords.java
 *		Copyright (c) 2003, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.brains2b.typewriter;

import java.util.ArrayList;

/** Class that implements one single static function <code>isReserved</code>
 * which checks if a <code>String</code> is a Java reserved word.
 * 
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10 [Oct 29, 2003]
 */
public class KeyWords {
	
	/** list of Java reserved words */
	private static ArrayList KEYWORDS= new ArrayList();
	
	static {
		KEYWORDS.add("abstract");
		KEYWORDS.add("double");
		KEYWORDS.add("int");
		KEYWORDS.add("strictfp");
		KEYWORDS.add("boolean");
		KEYWORDS.add("else");
		KEYWORDS.add("interface");
		KEYWORDS.add("super");
		KEYWORDS.add("break");
		KEYWORDS.add("extends");
		KEYWORDS.add("long");
		KEYWORDS.add("switch");
		KEYWORDS.add("byte");
		KEYWORDS.add("final");
		KEYWORDS.add("native");
		KEYWORDS.add("synchronized");
		KEYWORDS.add("case");
		KEYWORDS.add("finally");
		KEYWORDS.add("new");
		KEYWORDS.add("this");
		KEYWORDS.add("catch");
		KEYWORDS.add("float");
		KEYWORDS.add("package");
		KEYWORDS.add("throw");
		KEYWORDS.add("char");
		KEYWORDS.add("for");
		KEYWORDS.add("private");
		KEYWORDS.add("throws");
		KEYWORDS.add("class");
		KEYWORDS.add("goto");
		KEYWORDS.add("protected");
		KEYWORDS.add("transient");
		KEYWORDS.add("const");
		KEYWORDS.add("if");
		KEYWORDS.add("public");
		KEYWORDS.add("try");
		KEYWORDS.add("continue");
		KEYWORDS.add("implements");
		KEYWORDS.add("return");
		KEYWORDS.add("void");
		KEYWORDS.add("default");
		KEYWORDS.add("import");
		KEYWORDS.add("short");
		KEYWORDS.add("volatile");
		KEYWORDS.add("do");
		KEYWORDS.add("instanceof");
		KEYWORDS.add("static");
		KEYWORDS.add("while");
	}
	
	/**
	 * Default Constructor
	 * <p>constructor made private to prevent instantiation
	 */
	private KeyWords() {
		super();
	}
	
	/**
	 * check if a String is a Java reserved word/keyword 
	 * @param name String, the value to check
	 * @return boolean, true if the String is a keyword, otherwise false, also if the
	 * name is null.
	 */
	public static boolean isReserved(String name) {
		if (name==null) return false;
		return KEYWORDS.contains(name);
	}

}
